﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinSpellChecker;
using Infragistics.Win.IGControls;

namespace SpellCheckerTextCorrection93050
{
    public partial class Form1 : Form
    {
        IGContextMenu menu = new IGContextMenu();
        Error spellingError;

        public Form1()
        {
            InitializeComponent();

            this.Load += new EventHandler(Form1_Load);
        }

        void Form1_Load(object sender, EventArgs e)
        {


            // Set the style of the context menu to look like
            // Microsoft Word 2003.
            this.menu.Style = MenuStyle.Office2010;

            // Set the richtextbox's context menu to be the 
            // context menu we created earlier.
            this.ultraFormattedTextEditor1.ContextMenu = this.menu;

            // Set the User's Dictionary. If you don't have a 
            // dictionary, then leave out this line, we will test
            // for a user dictionary later.
           ultraSpellChecker1.UserDictionary = "custom.dict";


            ////set the dictionary to be Australian
            ultraSpellChecker1.Dictionary = "au-english-v2-whole.dict";
        }

        private void PopulateContextMenu(Error error)
        {
            // Clear all menu items in the context menu.
            this.menu.MenuItems.Clear();

            // Fill the context menu with the first five spelling
            // suggestions that WinSpellChecker comes up with.
            for (int i = 0; i < error.Suggestions.Count; i++)
            {
                if (i == 5) break;
                IGMenuItem menuItem =
                  new IGMenuItem(error.Suggestions[i].ToString(),
                  new EventHandler(this.menuItem_Click));
                this.menu.MenuItems.Add(menuItem);
            }

            // Add a separator to the context menu.
            IGMenuItem barBreak = new IGMenuItem("-");
            this.menu.MenuItems.Add(barBreak);

            // Add a menu item to the context menu that we will
            // later use to ignore all occurences of the right-
            // clicked word.
            IGMenuItem ignoreAll = new IGMenuItem("Ignore All",
              new EventHandler(this.ignoreAll_Click));
            this.menu.MenuItems.Add(ignoreAll);

            // Add a menu item to the context menu that we will
            // later use to add the right-clicked word to the
            // user's dictionary.
            IGMenuItem addToDictionary = new IGMenuItem("Add to Dictionary",
              new EventHandler(this.addToDictionary_Click));
            this.menu.MenuItems.Add(addToDictionary);

            // If there is no user dictionary, disable the "Add
            // to Dictionary" menu item.
            if (this.ultraSpellChecker1.UserDictionary == "")
                this.menu.MenuItems[this.menu.MenuItems.Count - 1].Enabled = false;
        }

        private void ultraFormattedTextEditor1_MouseDown(object sender, MouseEventArgs e)
        {
            if (e.Button == System.Windows.Forms.MouseButtons.Right)
            {
                // Create a new point for spellingError to use
                // to get the spelling error at point. The point
                // will be the mouse coordinates.
                Point point = new Point(e.X, e.Y);

                // Get the spelling error at the mouse's coordinates.
                this.spellingError =
                  this.ultraSpellChecker1.GetErrorAtPoint(this.ultraFormattedTextEditor1, point);

                // If there is no spelling error at the designated
                // coordinates, clear the context menu and cancel.
                if (spellingError == null)
                {
                    this.menu.MenuItems.Clear();
                    return;
                }
                else this.PopulateContextMenu(spellingError);
            }

        }

        private void menuItem_Click(object sender, EventArgs e)
        {
            IGMenuItem menuItem = sender as IGMenuItem;

            int selectSpellingError =
              (this.spellingError.EndIndex - this.spellingError.StartIndex) + 1;

            // The Select method takes in two arguments in this override:
            // the starting index of the selection and the length of the
            // selection. Once the propert text is selected, it is replaced
            // with the text of the menu item that the user clicked.
            //this.ultraFormattedTextEditor1.Select(this.spellingError.StartIndex, selectSpellingError);
            //this.ultraFormattedTextEditor1.SelectedText = menuItem.Text;

            this.ultraFormattedTextEditor1.EditInfo.SelectionStart = this.spellingError.StartIndex;
            this.ultraFormattedTextEditor1.EditInfo.SelectionLength = selectSpellingError;
            this.ultraFormattedTextEditor1.EditInfo.Editor.SelectedText = menuItem.Text;
            
        }

        private void ignoreAll_Click(object sender, EventArgs e)
        {
            // Ignore all occurences of the word that was right-clicked.
            this.ultraSpellChecker1.IgnoreAll(this.spellingError.CheckedWord.ToString());
        }

        private void addToDictionary_Click(object sender, EventArgs e)
        {
            // add the word that was right-clicked to the user's dictionary.
            this.ultraSpellChecker1.AddWordToUserDictionary(
              this.spellingError.CheckedWord.ToString());
        }


    }
}
